@@ -7,4 +7,4 @@ class ModelEvaluateRequest(BaseModel):
     data: List[Image]
     meta: Optional[Meta] = None
     models: List[Model]
-    mapping: Optional[Dict[str, str]]
+    mapping: Optional[Dict[str, Dict[str, str]]]
